@@ -2,7 +2,7 @@
 
 from pynvim.plugin.decorators import (autocmd, command, decode, encoding, function,
                                       plugin, rpc_export, shutdown_hook)
-from pynvim.plugin.host import Host
+from pynvim.plugin.host import Host  # type: ignore[attr-defined]
 
 
 __all__ = ('Host', 'plugin', 'rpc_export', 'command', 'autocmd',
